Changed function hipMemcpy_2D to hipMemcpyParam2D

[ROCm/clr commit: 24307fe5c4]
このコミットが含まれているのは:
Rahul Garg
2017-11-21 12:36:24 +05:30
コミット dc2c56c43d
3個のファイルの変更3行の追加3行の削除
+1 -1
ファイルの表示
@@ -1358,7 +1358,7 @@ hipError_t hipMalloc3DArray(hipArray_t *array,
* @see hipMemcpy, hipMemcpyToArray, hipMemcpy2DToArray, hipMemcpyFromArray, hipMemcpyToSymbol, hipMemcpyAsync * @see hipMemcpy, hipMemcpyToArray, hipMemcpy2DToArray, hipMemcpyFromArray, hipMemcpyToSymbol, hipMemcpyAsync
*/ */
hipError_t hipMemcpy2D(void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, hipMemcpyKind kind); hipError_t hipMemcpy2D(void* dst, size_t dpitch, const void* src, size_t spitch, size_t width, size_t height, hipMemcpyKind kind);
hipError_t hipMemcpy_2D(const hip_Memcpy2D* pCopy); hipError_t hipMemcpyParam2D(const hip_Memcpy2D* pCopy);
/** /**
* @brief Copies data between host and device. * @brief Copies data between host and device.
+1 -1
ファイルの表示
@@ -70,7 +70,7 @@ bool runTest(int argc, char **argv)
copyParam.srcPitch = width * sizeof(float); copyParam.srcPitch = width * sizeof(float);
copyParam.widthInBytes = copyParam.srcPitch; copyParam.widthInBytes = copyParam.srcPitch;
copyParam.height = height; copyParam.height = height;
hipMemcpy_2D(&copyParam); hipMemcpyParam2D(&copyParam);
textureReference* texref; textureReference* texref;
hipModuleGetTexRef(&texref, Module, "tex"); hipModuleGetTexRef(&texref, Module, "tex");
+1 -1
ファイルの表示
@@ -1134,7 +1134,7 @@ hipError_t hipMemcpy2D(void* dst, size_t dpitch, const void* src, size_t spitch,
return ihipLogStatus(e); return ihipLogStatus(e);
} }
hipError_t hipMemcpy_2D(const hip_Memcpy2D* pCopy) hipError_t hipMemcpyParam2D(const hip_Memcpy2D* pCopy)
{ {
HIP_INIT_SPECIAL_API((TRACE_MCMD), pCopy); HIP_INIT_SPECIAL_API((TRACE_MCMD), pCopy);
hipError_t e = hipSuccess; hipError_t e = hipSuccess;